Bifrost: CDBG_Build_opt Struct Reference

Bifrost

Data Fields
CDBG_Build_opt Struct Reference

Most members of this structure are parameters for CompactedDBG<U, G>::build(), except for: More...

Inherited by CCDBG_Build_opt.

## Data Fields
bool | verbose
| Print information messages during execution if true. More...
size_t | nb_threads
| Number of threads to use for building the graph. More...
size_t | read_chunksize
| Number of reads a thread can read and process at a time. More...
size_t | nb_bits_unique_kmers_bf
| Number of Bloom filter bits per k-mer occurring at least once in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in. More...
size_t | nb_bits_non_unique_kmers_bf
| Number of Bloom filter bits per k-mer occurring at least twice in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in. More...
string | inFilenameBBF
| String containing the name of a Bloom filter file that is generated by CompactedDBG<U, G>::filter. More...
string | outFilenameBBF
| String containing the name of a Bloom filter file that will be generated by CompactedDBG<U, G>::filter. More...
vector< string > | filename_seq_in
| Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction. More...
vector< string > | filename_ref_in
| Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction. More...
size_t | k
| Length of k-mers (not used by CompactedDBG<U, G>::build). More...
size_t | g
| Length of g-mers, the minimizers, such that g < k (not used by CompactedDBG<U, G>::build). More...
bool | build
| Boolean indicating if the graph must be built. More...
bool | update
| Boolean indicating if the graph must be updated. More...
bool | clipTips
| Clip short tips (length < 2k) of the graph (not used by CompactedDBG<U, G>::build). More...
bool | deleteIsolated
| Remove short isolated unitigs (length < 2k) of the graph (not used by CompactedDBG<U, G>::build). More...
bool | useMercyKmers
| Keep in the graph low coverage k-mers (cov=1) connecting tips of the graph. More...
bool | outputGFA
| Boolean indicating if the graph is written to a GFA file (true) or if the unitigs are written to a FASTA file (false). More...
string | prefixFilenameOut
| Prefix for the name of the file to which the graph must be written. More...
string | filename_graph_in
| String containing the name of a GFA file to read using CompactedDBG<U, G>::read. More...

## Detailed Description

Most members of this structure are parameters for CompactedDBG<U, G>::build(), except for:

- CDBG_Build_opt::k and CDBG_Build_opt::g as they are parameters of the graph constructor.
- CDBG_Build_opt::clipTips, CDBG_Build_opt::deleteIsolated and CDBG_Build_opt::useMercyKmers are used by CompactedDBG<U, G>::simplify
- CDBG_Build_opt::prefixFilenameOut and CDBG_Build_opt::outputGFA are used by CompactedDBG<U, G>::write
- CDBG_Build_opt::filename_graph_in is used by CompactedDBG<U, G>::read
- CDBG_Build_opt::build and CDBG_Build_opt::update Most parameters have default values. An example of using such a structure is shown in src/Bifrost.cpp.

## Field Documentation

## ◆ build

CDBG_Build_opt::build

Boolean indicating if the graph must be built.

This parameter is not used by any function of CompactedDBG<U, G> but is used by the Bifrost CLI. Default is false.

## ◆ clipTips

CDBG_Build_opt::clipTips

Clip short tips (length < 2k) of the graph (not used by CompactedDBG<U, G>::build).

Default is false.

## ◆ deleteIsolated

CDBG_Build_opt::deleteIsolated

Remove short isolated unitigs (length < 2k) of the graph (not used by CompactedDBG<U, G>::build).

Default is false.

## ◆ filename_graph_in

CDBG_Build_opt::filename_graph_in

String containing the name of a GFA file to read using CompactedDBG<U, G>::read.

Default is empty string (no input file).

## ◆ filename_ref_in

CDBG_Build_opt::filename_ref_in

Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction.

Each such file will NOT be filtered before construction such that all k-mers in those files will be used. Mandatory parameter.

## ◆ filename_seq_in

CDBG_Build_opt::filename_seq_in

Vector of strings, each string is the name of a FASTA/FASTQ/GFA file to use for the graph construction.

Each such file will be filtered before construction such that k-mers with exactly one occurrence in those files will be discarded. Mandatory parameter.

## ◆ g

CDBG_Build_opt::g

Length of g-mers, the minimizers, such that g < k (not used by CompactedDBG<U, G>::build).

Default is 23.

## ◆ inFilenameBBF

CDBG_Build_opt::inFilenameBBF

String containing the name of a Bloom filter file that is generated by CompactedDBG<U, G>::filter.

If empty, CompactedDBG<U, G>::filter is called. Otherwise, the Bloom filter is loaded from this file and CompactedDBG<U, G>::filter is not called. Note that you need such a Bloom filter even in reference mode. Default is empty string (no input file).

## ◆ k

CDBG_Build_opt::k

Length of k-mers (not used by CompactedDBG<U, G>::build).

Default is 31.

## ◆ nb_bits_non_unique_kmers_bf

CDBG_Build_opt::nb_bits_non_unique_kmers_bf

Number of Bloom filter bits per k-mer occurring at least twice in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in.

Default is 14.

## ◆ nb_bits_unique_kmers_bf

CDBG_Build_opt::nb_bits_unique_kmers_bf

Number of Bloom filter bits per k-mer occurring at least once in the FASTA/FASTQ/GFA files of CDBG_Build_opt::filename_in.

Default is 14.

## ◆ nb_threads

CDBG_Build_opt::nb_threads

Number of threads to use for building the graph.

Default is 1.

## ◆ outFilenameBBF

CDBG_Build_opt::outFilenameBBF

String containing the name of a Bloom filter file that will be generated by CompactedDBG<U, G>::filter.

If empty, the file is not created. Otherwise, the Bloom filter is written to this file. Default is empty string (no output file).

## ◆ outputGFA

CDBG_Build_opt::outputGFA

Boolean indicating if the graph is written to a GFA file (true) or if the unitigs are written to a FASTA file (false).

Default is true.

## ◆ prefixFilenameOut

CDBG_Build_opt::prefixFilenameOut

Prefix for the name of the file to which the graph must be written.

Mandatory parameter.

## ◆ read_chunksize

CDBG_Build_opt::read_chunksize

Number of reads a thread can read and process at a time.

Default is 64.

## ◆ update

CDBG_Build_opt::update

Boolean indicating if the graph must be updated.

This parameter is not used by any function of CompactedDBG<U, G> but is used by the Bifrost CLI. Default is false.

## ◆ useMercyKmers

CDBG_Build_opt::useMercyKmers

Keep in the graph low coverage k-mers (cov=1) connecting tips of the graph.

Default is false.

## ◆ verbose

CDBG_Build_opt::verbose

Print information messages during execution if true.

Default is false.

The documentation for this struct was generated from the following file:

- src/CompactedDBG.hpp